%define upstream_name Path-Iterator-Rule
%define upstream_version 1.014

%{?perl_default_filter}

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 3

Summary:    Iterative, recursive file finder
License:    ASL 2.0
Group:      Development/Perl
Url:        http://search.cpan.org/dist/%{upstream_name}
Source0:    http://www.cpan.org/modules/by-module/IO/DAGOLDEN/%{upstream_name}-%{upstream_version}.tar.gz

BuildConflicts:	cpanminus

BuildRequires: perl(Carp)
BuildRequires: perl(Exporter)
BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(File::Basename)
BuildRequires: perl(File::Spec)
BuildRequires: perl(File::Temp)
BuildRequires: perl(File::pushd)
BuildRequires: perl(List::Util)
BuildRequires: perl(Number::Compare) >= 0.20.0
BuildRequires: perl(Path::Tiny)
BuildRequires: perl(Scalar::Util)
BuildRequires: perl(Test::Deep)
BuildRequires: perl(Test::Filename) >= 0.30.0
BuildRequires: perl(Test::More) >= 0.920.0
BuildRequires: perl(Text::Glob)
BuildRequires: perl(Try::Tiny)
BuildRequires: perl(if)
BuildRequires: perl(lib)
BuildRequires: perl(parent)
BuildRequires: perl(strict)
BuildRequires: perl(warnings)
BuildRequires: perl(warnings::register)
BuildArch:  noarch

%description
This module iterates over files and directories to identify ones
matching a user-defined set of rules. The API is based heavily on
File::Find::Rule, but with more explicit distinction between matching
rules and options that influence how directories are searched. A
"Path::Iterator::Rule" object is a collection of rules (match criteria)
with methods to add additional criteria. Options that control directory
traversal are given as arguments to the method that generates an
iterator.

Here is a summary of features for comparison to other file finding
modules:

*   provides many "helper" methods for specifying rules

*   offers (lazy) iterator and flattened list interfaces

*   custom rules implemented with callbacks

*   breadth-first (default) or pre- or post-order depth-first searching

*   follows symlinks (by default, but can be disabled)

*   directories visited only once (no infinite loop; can be disabled)

*   doesn't chdir during operation

*   provides an API for extensions

As a convenience, the PIR module is an empty subclass of this one that
is less arduous to type for one-liners.

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%__perl Makefile.PL INSTALLDIRS=vendor

%{make}

%check
%{make} test

%install
%make_install

%files
%doc Changes LICENSE META.json META.yml MYMETA.yml README examples
%{_mandir}/man3/*
%{perl_vendorlib}/*

%changelog
* Wed Feb 12 2020 umeabot <umeabot> 1.14.0-3.mga8
+ Revision: 1505931
- Mageia 8 Mass Rebuild

* Thu Sep 20 2018 umeabot <umeabot> 1.14.0-2.mga7
+ Revision: 1285707
- Mageia 7 Mass Rebuild

* Fri Jun 29 2018 tv <tv> 1.14.0-1.mga7
+ Revision: 1240681
- update to 1.014

* Fri Jun 22 2018 tv <tv> 1.13.0-1.mga7
+ Revision: 1238742
- update to 1.013

* Wed Oct 04 2017 tv <tv> 1.12.0-1.mga7
+ Revision: 1168667
- update to 1.012

* Sun Jun 19 2016 pterjan <pterjan> 1.11.0-2.mga6
+ Revision: 1031893
- Rebuild for perl 5.22.2

* Sun Mar 13 2016 shlomif <shlomif> 1.11.0-1.mga6
+ Revision: 989836
- update to 1.011

* Fri Feb 19 2016 umeabot <umeabot> 1.9.0-2.mga6
+ Revision: 970026
- Mageia 6 Mass Rebuild

* Mon Sep 28 2015 sander85 <sander85> 1.9.0-1.mga6
+ Revision: 884781
- update to 1.009

* Wed Oct 15 2014 umeabot <umeabot> 1.8.0-3.mga5
+ Revision: 740199
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.8.0-2.mga5
+ Revision: 685916
- Mageia 5 Mass Rebuild

* Thu Feb 06 2014 sander85 <sander85> 1.8.0-1.mga5
+ Revision: 584500
- update to 1.008

* Sat Oct 19 2013 umeabot <umeabot> 1.5.0-2.mga4
+ Revision: 531599
- Mageia 4 Mass Rebuild

* Tue Aug 06 2013 sander85 <sander85> 1.5.0-1.mga4
+ Revision: 464236
- imported package perl-Path-Iterator-Rule

